<img src="https://raw.githubusercontent.com/jaedb/iris/master/src/assets/logo.png" width="128" />

Iris (formerly known as Spotmop) is an extension for the Mopidy music server. With support for Spotify, LastFM, Snapcast, Icecast and many other extensions, Iris is the software that brings all your music into one user-friendly and unified interface.

Built and maintained by James Barnsley.

[![npm](https://img.shields.io/npm/v/mopidy-iris.svg?style=flat-square)]()
![badge](https://img.shields.io/pypi/v/mopidy-iris.svg?style=flat-square)
![badge](https://img.shields.io/badge/unique_monthly_users-4,000+-brightgreen.svg?style=flat-square)
[![badge](https://img.shields.io/badge/donate-paypal-blue.svg?style=flat-square)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=james%40barnsley%2enz&lc=NZ&item_name=James%20Barnsley&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_LG%2egif%3aNonHosted)

Features
--------

* Full web-based interface controls for Mopidy
* Improved support for local libraries (powered by Mopidy-Local-Sqlite)
* Browse and manage your playlists and tracks
* Discover new, popular and related music (powered by Spotify)
* Freely hosted, auto-updated interface available ([beta](https://jaedb.github.io/Iris/#/))
* Integration with:
  * [Spotify](https://developer.spotify.com/web-api/)
  * [LastFM](https://www.last.fm/api)
  * [Genius](https://docs.genius.com/)
  * [Snapcast](https://github.com/badaix/snapcast/)
  * [Icecast](http://icecast.org/)

![Overview](https://raw.githubusercontent.com/jaedb/iris/master/screenshot.jpg)


Requirements
--------

* Mopidy
* Mopidy-Spotify (recommended, not required)
* Mopidy-Local-Sqlite (recommended, not required)

Getting started
-------

* [Installation](https://github.com/jaedb/Iris/wiki/Getting-started#installing)
* [Debugging](https://github.com/jaedb/Iris/wiki/Advanced#debugging)
* [Issues and requests](https://github.com/jaedb/Iris/wiki/Support#before-you-log-an-issue)
* [Changelog](https://github.com/jaedb/iris/releases)

